# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: demoparser/protobufs/netmessages.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='demoparser/protobufs/netmessages.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n&demoparser/protobufs/netmessages.proto\x1a google/protobuf/descriptor.proto\"-\n\nCMsgVector\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\"$\n\x0c\x43MsgVector2D\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\"-\n\nCMsgQAngle\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\"6\n\x08\x43MsgRGBA\x12\t\n\x01r\x18\x01 \x01(\x05\x12\t\n\x01g\x18\x02 \x01(\x05\x12\t\n\x01\x62\x18\x03 \x01(\x05\x12\t\n\x01\x61\x18\x04 \x01(\x05\"\xac\x01\n\x0c\x43NETMsg_Tick\x12\x0c\n\x04tick\x18\x01 \x01(\r\x12\x1c\n\x14host_computationtime\x18\x04 \x01(\r\x12*\n\"host_computationtime_std_deviation\x18\x05 \x01(\r\x12)\n!host_framestarttime_std_deviation\x18\x06 \x01(\r\x12\x19\n\x11hltv_replay_flags\x18\x07 \x01(\r\"$\n\x11\x43NETMsg_StringCmd\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\t\"\x8a\x01\n\x13\x43NETMsg_SignonState\x12\x14\n\x0csignon_state\x18\x01 \x01(\r\x12\x13\n\x0bspawn_count\x18\x02 \x01(\r\x12\x1a\n\x12num_server_players\x18\x03 \x01(\r\x12\x1a\n\x12players_networkids\x18\x04 \x03(\t\x12\x10\n\x08map_name\x18\x05 \x01(\t\"k\n\nCMsg_CVars\x12\x1f\n\x05\x63vars\x18\x01 \x03(\x0b\x32\x10.CMsg_CVars.CVar\x1a<\n\x04\x43Var\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x17\n\x0f\x64ictionary_name\x18\x03 \x01(\r\"1\n\x11\x43NETMsg_SetConVar\x12\x1c\n\x07\x63onvars\x18\x01 \x01(\x0b\x32\x0b.CMsg_CVars\"\r\n\x0b\x43NETMsg_NOP\"\"\n\x12\x43NETMsg_Disconnect\x12\x0c\n\x04text\x18\x01 \x01(\t\"a\n\x0c\x43NETMsg_File\x12\x13\n\x0btransfer_id\x18\x01 \x01(\x05\x12\x11\n\tfile_name\x18\x02 \x01(\t\x12\x1b\n\x13is_replay_demo_file\x18\x03 \x01(\x08\x12\x0c\n\x04\x64\x65ny\x18\x04 \x01(\x08\"\'\n\x17\x43NETMsg_SplitScreenUser\x12\x0c\n\x04slot\x18\x01 \x01(\x05\":\n\x18\x43NETMsg_PlayerAvatarData\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\x0b\n\x03rgb\x18\x02 \x01(\x0c\"\xa6\x01\n\x12\x43\x43LCMsg_ClientInfo\x12\x16\n\x0esend_table_crc\x18\x01 \x01(\x07\x12\x14\n\x0cserver_count\x18\x02 \x01(\r\x12\x0f\n\x07is_hltv\x18\x03 \x01(\x08\x12\x11\n\tis_replay\x18\x04 \x01(\x08\x12\x12\n\nfriends_id\x18\x05 \x01(\r\x12\x14\n\x0c\x66riends_name\x18\x06 \x01(\t\x12\x14\n\x0c\x63ustom_files\x18\x07 \x03(\x07\"S\n\x0c\x43\x43LCMsg_Move\x12\x1b\n\x13num_backup_commands\x18\x01 \x01(\r\x12\x18\n\x10num_new_commands\x18\x02 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"\xc0\x01\n\x11\x43\x43LCMsg_VoiceData\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x0c\n\x04xuid\x18\x02 \x01(\x06\x12;\n\x06\x66ormat\x18\x03 \x01(\x0e\x32\x12.VoiceDataFormat_t:\x17VOICEDATA_FORMAT_ENGINE\x12\x16\n\x0esequence_bytes\x18\x04 \x01(\x05\x12\x16\n\x0esection_number\x18\x05 \x01(\r\x12\"\n\x1auncompressed_sample_offset\x18\x06 \x01(\r\"A\n\x13\x43\x43LCMsg_BaselineAck\x12\x15\n\rbaseline_tick\x18\x01 \x01(\x05\x12\x13\n\x0b\x62\x61seline_nr\x18\x02 \x01(\x05\"*\n\x14\x43\x43LCMsg_ListenEvents\x12\x12\n\nevent_mask\x18\x01 \x03(\x07\"\\\n\x18\x43\x43LCMsg_RespondCvarValue\x12\x0e\n\x06\x63ookie\x18\x01 \x01(\x05\x12\x13\n\x0bstatus_code\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05value\x18\x04 \x01(\t\"\xeb\x01\n\x14\x43\x43LCMsg_FileCRCCheck\x12\x11\n\tcode_path\x18\x01 \x01(\x05\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x15\n\rcode_filename\x18\x03 \x01(\x05\x12\x10\n\x08\x66ilename\x18\x04 \x01(\t\x12\x15\n\rfile_fraction\x18\x05 \x01(\x05\x12\x0b\n\x03md5\x18\x06 \x01(\x0c\x12\x0b\n\x03\x63rc\x18\x07 \x01(\r\x12\x16\n\x0e\x66ile_hash_type\x18\x08 \x01(\x05\x12\x10\n\x08\x66ile_len\x18\t \x01(\x05\x12\x14\n\x0cpack_file_id\x18\n \x01(\x05\x12\x18\n\x10pack_file_number\x18\x0b \x01(\x05\"+\n\x17\x43\x43LCMsg_LoadingProgress\x12\x10\n\x08progress\x18\x01 \x01(\x05\":\n\x1a\x43\x43LCMsg_SplitPlayerConnect\x12\x1c\n\x07\x63onvars\x18\x01 \x01(\x0b\x32\x0b.CMsg_CVars\")\n\x14\x43\x43LCMsg_CmdKeyValues\x12\x11\n\tkeyvalues\x18\x01 \x01(\x0c\"\xea\x03\n\x12\x43SVCMsg_ServerInfo\x12\x10\n\x08protocol\x18\x01 \x01(\x05\x12\x14\n\x0cserver_count\x18\x02 \x01(\x05\x12\x14\n\x0cis_dedicated\x18\x03 \x01(\x08\x12 \n\x18is_official_valve_server\x18\x04 \x01(\x08\x12\x0f\n\x07is_hltv\x18\x05 \x01(\x08\x12\x11\n\tis_replay\x18\x06 \x01(\x08\x12%\n\x1dis_redirecting_to_proxy_relay\x18\x15 \x01(\x08\x12\x0c\n\x04\x63_os\x18\x07 \x01(\x05\x12\x0f\n\x07map_crc\x18\x08 \x01(\x07\x12\x12\n\nclient_crc\x18\t \x01(\x07\x12\x18\n\x10string_table_crc\x18\n \x01(\x07\x12\x13\n\x0bmax_clients\x18\x0b \x01(\x05\x12\x13\n\x0bmax_classes\x18\x0c \x01(\x05\x12\x13\n\x0bplayer_slot\x18\r \x01(\x05\x12\x15\n\rtick_interval\x18\x0e \x01(\x02\x12\x10\n\x08game_dir\x18\x0f \x01(\t\x12\x10\n\x08map_name\x18\x10 \x01(\t\x12\x16\n\x0emap_group_name\x18\x11 \x01(\t\x12\x10\n\x08sky_name\x18\x12 \x01(\t\x12\x11\n\thost_name\x18\x13 \x01(\t\x12\x11\n\tpublic_ip\x18\x14 \x01(\r\x12\x12\n\nugc_map_id\x18\x16 \x01(\x04\"\xa4\x01\n\x11\x43SVCMsg_ClassInfo\x12\x18\n\x10\x63reate_on_client\x18\x01 \x01(\x08\x12+\n\x07\x63lasses\x18\x02 \x03(\x0b\x32\x1a.CSVCMsg_ClassInfo.class_t\x1aH\n\x07\x63lass_t\x12\x10\n\x08\x63lass_id\x18\x01 \x01(\x05\x12\x17\n\x0f\x64\x61ta_table_name\x18\x02 \x01(\t\x12\x12\n\nclass_name\x18\x03 \x01(\t\"\xb0\x02\n\x11\x43SVCMsg_SendTable\x12\x0e\n\x06is_end\x18\x01 \x01(\x08\x12\x16\n\x0enet_table_name\x18\x02 \x01(\t\x12\x15\n\rneeds_decoder\x18\x03 \x01(\x08\x12,\n\x05props\x18\x04 \x03(\x0b\x32\x1d.CSVCMsg_SendTable.sendprop_t\x1a\xad\x01\n\nsendprop_t\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x10\n\x08var_name\x18\x02 \x01(\t\x12\r\n\x05\x66lags\x18\x03 \x01(\x05\x12\x10\n\x08priority\x18\x04 \x01(\x05\x12\x0f\n\x07\x64t_name\x18\x05 \x01(\t\x12\x14\n\x0cnum_elements\x18\x06 \x01(\x05\x12\x11\n\tlow_value\x18\x07 \x01(\x02\x12\x12\n\nhigh_value\x18\x08 \x01(\x02\x12\x10\n\x08num_bits\x18\t \x01(\x05\"\x1d\n\rCSVCMsg_Print\x12\x0c\n\x04text\x18\x01 \x01(\t\"\"\n\x10\x43SVCMsg_SetPause\x12\x0e\n\x06paused\x18\x01 \x01(\x08\"\'\n\x0f\x43SVCMsg_SetView\x12\x14\n\x0c\x65ntity_index\x18\x01 \x01(\x05\"\xca\x01\n\x19\x43SVCMsg_CreateStringTable\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0bmax_entries\x18\x02 \x01(\x05\x12\x13\n\x0bnum_entries\x18\x03 \x01(\x05\x12\x1c\n\x14user_data_fixed_size\x18\x04 \x01(\x08\x12\x16\n\x0euser_data_size\x18\x05 \x01(\x05\x12\x1b\n\x13user_data_size_bits\x18\x06 \x01(\x05\x12\r\n\x05\x66lags\x18\x07 \x01(\x05\x12\x13\n\x0bstring_data\x18\x08 \x01(\x0c\"_\n\x19\x43SVCMsg_UpdateStringTable\x12\x10\n\x08table_id\x18\x01 \x01(\x05\x12\x1b\n\x13num_changed_entries\x18\x02 \x01(\x05\x12\x13\n\x0bstring_data\x18\x03 \x01(\x0c\"G\n\x11\x43SVCMsg_VoiceInit\x12\x0f\n\x07quality\x18\x01 \x01(\x05\x12\r\n\x05\x63odec\x18\x02 \x01(\t\x12\x12\n\x07version\x18\x03 \x01(\x05:\x01\x30\"\x8f\x02\n\x11\x43SVCMsg_VoiceData\x12\x0e\n\x06\x63lient\x18\x01 \x01(\x05\x12\x11\n\tproximity\x18\x02 \x01(\x08\x12\x0c\n\x04xuid\x18\x03 \x01(\x06\x12\x14\n\x0c\x61udible_mask\x18\x04 \x01(\x05\x12\x12\n\nvoice_data\x18\x05 \x01(\x0c\x12\x0e\n\x06\x63\x61ster\x18\x06 \x01(\x08\x12;\n\x06\x66ormat\x18\x07 \x01(\x0e\x32\x12.VoiceDataFormat_t:\x17VOICEDATA_FORMAT_ENGINE\x12\x16\n\x0esequence_bytes\x18\x08 \x01(\x05\x12\x16\n\x0esection_number\x18\t \x01(\r\x12\"\n\x1auncompressed_sample_offset\x18\n \x01(\r\"@\n\x10\x43SVCMsg_FixAngle\x12\x10\n\x08relative\x18\x01 \x01(\x08\x12\x1a\n\x05\x61ngle\x18\x02 \x01(\x0b\x32\x0b.CMsgQAngle\"4\n\x16\x43SVCMsg_CrosshairAngle\x12\x1a\n\x05\x61ngle\x18\x01 \x01(\x0b\x32\x0b.CMsgQAngle\"\'\n\x10\x43SVCMsg_Prefetch\x12\x13\n\x0bsound_index\x18\x01 \x01(\x05\"\x8a\x01\n\x10\x43SVCMsg_BSPDecal\x12\x18\n\x03pos\x18\x01 \x01(\x0b\x32\x0b.CMsgVector\x12\x1b\n\x13\x64\x65\x63\x61l_texture_index\x18\x02 \x01(\x05\x12\x14\n\x0c\x65ntity_index\x18\x03 \x01(\x05\x12\x13\n\x0bmodel_index\x18\x04 \x01(\x05\x12\x14\n\x0clow_priority\x18\x05 \x01(\x08\"z\n\x13\x43SVCMsg_SplitScreen\x12?\n\x04type\x18\x01 \x01(\x0e\x32\x18.ESplitScreenMessageType:\x17MSG_SPLITSCREEN_ADDUSER\x12\x0c\n\x04slot\x18\x02 \x01(\x05\x12\x14\n\x0cplayer_index\x18\x03 \x01(\x05\"9\n\x14\x43SVCMsg_GetCvarValue\x12\x0e\n\x06\x63ookie\x18\x01 \x01(\x05\x12\x11\n\tcvar_name\x18\x02 \x01(\t\"<\n\x0c\x43SVCMsg_Menu\x12\x13\n\x0b\x64ialog_type\x18\x01 \x01(\x05\x12\x17\n\x0fmenu_key_values\x18\x02 \x01(\x0c\"N\n\x13\x43SVCMsg_UserMessage\x12\x10\n\x08msg_type\x18\x01 \x01(\x05\x12\x10\n\x08msg_data\x18\x02 \x01(\x0c\x12\x13\n\x0bpassthrough\x18\x03 \x01(\x05\"(\n\x14\x43SVCMsg_PaintmapData\x12\x10\n\x08paintmap\x18\x01 \x01(\x0c\"\xa6\x02\n\x11\x43SVCMsg_GameEvent\x12\x12\n\nevent_name\x18\x01 \x01(\t\x12\x0f\n\x07\x65ventid\x18\x02 \x01(\x05\x12&\n\x04keys\x18\x03 \x03(\x0b\x32\x18.CSVCMsg_GameEvent.key_t\x12\x13\n\x0bpassthrough\x18\x04 \x01(\x05\x1a\xae\x01\n\x05key_t\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x12\n\nval_string\x18\x02 \x01(\t\x12\x11\n\tval_float\x18\x03 \x01(\x02\x12\x10\n\x08val_long\x18\x04 \x01(\x05\x12\x11\n\tval_short\x18\x05 \x01(\x05\x12\x10\n\x08val_byte\x18\x06 \x01(\x05\x12\x10\n\x08val_bool\x18\x07 \x01(\x08\x12\x12\n\nval_uint64\x18\x08 \x01(\x04\x12\x13\n\x0bval_wstring\x18\t \x01(\x0c\"\xd1\x01\n\x15\x43SVCMsg_GameEventList\x12\x38\n\x0b\x64\x65scriptors\x18\x01 \x03(\x0b\x32#.CSVCMsg_GameEventList.descriptor_t\x1a#\n\x05key_t\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x1aY\n\x0c\x64\x65scriptor_t\x12\x0f\n\x07\x65ventid\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12*\n\x04keys\x18\x03 \x03(\x0b\x32\x1c.CSVCMsg_GameEventList.key_t\"R\n\x14\x43SVCMsg_TempEntities\x12\x10\n\x08reliable\x18\x01 \x01(\x08\x12\x13\n\x0bnum_entries\x18\x02 \x01(\x05\x12\x13\n\x0b\x65ntity_data\x18\x03 \x01(\x0c\"\xac\x01\n\x16\x43SVCMsg_PacketEntities\x12\x13\n\x0bmax_entries\x18\x01 \x01(\x05\x12\x17\n\x0fupdated_entries\x18\x02 \x01(\x05\x12\x10\n\x08is_delta\x18\x03 \x01(\x08\x12\x17\n\x0fupdate_baseline\x18\x04 \x01(\x08\x12\x10\n\x08\x62\x61seline\x18\x05 \x01(\x05\x12\x12\n\ndelta_from\x18\x06 \x01(\x05\x12\x13\n\x0b\x65ntity_data\x18\x07 \x01(\x0c\"\xb6\x03\n\x0e\x43SVCMsg_Sounds\x12\x16\n\x0ereliable_sound\x18\x01 \x01(\x08\x12+\n\x06sounds\x18\x02 \x03(\x0b\x32\x1b.CSVCMsg_Sounds.sounddata_t\x1a\xde\x02\n\x0bsounddata_t\x12\x10\n\x08origin_x\x18\x01 \x01(\x11\x12\x10\n\x08origin_y\x18\x02 \x01(\x11\x12\x10\n\x08origin_z\x18\x03 \x01(\x11\x12\x0e\n\x06volume\x18\x04 \x01(\r\x12\x13\n\x0b\x64\x65lay_value\x18\x05 \x01(\x02\x12\x17\n\x0fsequence_number\x18\x06 \x01(\x05\x12\x14\n\x0c\x65ntity_index\x18\x07 \x01(\x05\x12\x0f\n\x07\x63hannel\x18\x08 \x01(\x05\x12\r\n\x05pitch\x18\t \x01(\x05\x12\r\n\x05\x66lags\x18\n \x01(\x05\x12\x11\n\tsound_num\x18\x0b \x01(\r\x12\x18\n\x10sound_num_handle\x18\x0c \x01(\x07\x12\x16\n\x0espeaker_entity\x18\r \x01(\x05\x12\x13\n\x0brandom_seed\x18\x0e \x01(\x05\x12\x13\n\x0bsound_level\x18\x0f \x01(\x05\x12\x13\n\x0bis_sentence\x18\x10 \x01(\x08\x12\x12\n\nis_ambient\x18\x11 \x01(\x08\"J\n\x11\x43SVCMsg_EntityMsg\x12\x11\n\tent_index\x18\x01 \x01(\x05\x12\x10\n\x08\x63lass_id\x18\x02 \x01(\x05\x12\x10\n\x08\x65nt_data\x18\x03 \x01(\x0c\")\n\x14\x43SVCMsg_CmdKeyValues\x12\x11\n\tkeyvalues\x18\x01 \x01(\x0c\"<\n\x15\x43SVCMsg_EncryptedData\x12\x11\n\tencrypted\x18\x01 \x01(\x0c\x12\x10\n\x08key_type\x18\x02 \x01(\x05\"\xc6\x01\n\x12\x43SVCMsg_HltvReplay\x12\r\n\x05\x64\x65lay\x18\x01 \x01(\x05\x12\x16\n\x0eprimary_target\x18\x02 \x01(\x05\x12\x16\n\x0ereplay_stop_at\x18\x03 \x01(\x05\x12\x17\n\x0freplay_start_at\x18\x04 \x01(\x05\x12\x1d\n\x15replay_slowdown_begin\x18\x05 \x01(\x05\x12\x1b\n\x13replay_slowdown_end\x18\x06 \x01(\x05\x12\x1c\n\x14replay_slowdown_rate\x18\x07 \x01(\x02\"\x8b\x01\n\x12\x43\x43LCMsg_HltvReplay\x12\x0f\n\x07request\x18\x01 \x01(\x05\x12\x17\n\x0fslowdown_length\x18\x02 \x01(\x02\x12\x15\n\rslowdown_rate\x18\x03 \x01(\x02\x12 \n\x18primary_target_ent_index\x18\x04 \x01(\x05\x12\x12\n\nevent_time\x18\x05 \x01(\x02\"(\n\x19\x43SVCMsg_Broadcast_Command\x12\x0b\n\x03\x63md\x18\x01 \x01(\t*\xb9\x01\n\x0cNET_Messages\x12\x0b\n\x07net_NOP\x10\x00\x12\x12\n\x0enet_Disconnect\x10\x01\x12\x0c\n\x08net_File\x10\x02\x12\x17\n\x13net_SplitScreenUser\x10\x03\x12\x0c\n\x08net_Tick\x10\x04\x12\x11\n\rnet_StringCmd\x10\x05\x12\x11\n\rnet_SetConVar\x10\x06\x12\x13\n\x0fnet_SignonState\x10\x07\x12\x18\n\x14net_PlayerAvatarData\x10\x64*\x94\x02\n\x0c\x43LC_Messages\x12\x12\n\x0e\x63lc_ClientInfo\x10\x08\x12\x0c\n\x08\x63lc_Move\x10\t\x12\x11\n\rclc_VoiceData\x10\n\x12\x13\n\x0f\x63lc_BaselineAck\x10\x0b\x12\x14\n\x10\x63lc_ListenEvents\x10\x0c\x12\x18\n\x14\x63lc_RespondCvarValue\x10\r\x12\x14\n\x10\x63lc_FileCRCCheck\x10\x0e\x12\x17\n\x13\x63lc_LoadingProgress\x10\x0f\x12\x1a\n\x16\x63lc_SplitPlayerConnect\x10\x10\x12\x15\n\x11\x63lc_ClientMessage\x10\x11\x12\x14\n\x10\x63lc_CmdKeyValues\x10\x12\x12\x12\n\x0e\x63lc_HltvReplay\x10\x14*L\n\x11VoiceDataFormat_t\x12\x1a\n\x16VOICEDATA_FORMAT_STEAM\x10\x00\x12\x1b\n\x17VOICEDATA_FORMAT_ENGINE\x10\x01*y\n\x17\x45SplitScreenMessageType\x12\x1b\n\x17MSG_SPLITSCREEN_ADDUSER\x10\x00\x12\x1e\n\x1aMSG_SPLITSCREEN_REMOVEUSER\x10\x01\x12\x1d\n\x19MSG_SPLITSCREEN_TYPE_BITS\x10\x01\x1a\x02\x10\x01*\xe3\x04\n\x0cSVC_Messages\x12\x12\n\x0esvc_ServerInfo\x10\x08\x12\x11\n\rsvc_SendTable\x10\t\x12\x11\n\rsvc_ClassInfo\x10\n\x12\x10\n\x0csvc_SetPause\x10\x0b\x12\x19\n\x15svc_CreateStringTable\x10\x0c\x12\x19\n\x15svc_UpdateStringTable\x10\r\x12\x11\n\rsvc_VoiceInit\x10\x0e\x12\x11\n\rsvc_VoiceData\x10\x0f\x12\r\n\tsvc_Print\x10\x10\x12\x0e\n\nsvc_Sounds\x10\x11\x12\x0f\n\x0bsvc_SetView\x10\x12\x12\x10\n\x0csvc_FixAngle\x10\x13\x12\x16\n\x12svc_CrosshairAngle\x10\x14\x12\x10\n\x0csvc_BSPDecal\x10\x15\x12\x13\n\x0fsvc_SplitScreen\x10\x16\x12\x13\n\x0fsvc_UserMessage\x10\x17\x12\x15\n\x11svc_EntityMessage\x10\x18\x12\x11\n\rsvc_GameEvent\x10\x19\x12\x16\n\x12svc_PacketEntities\x10\x1a\x12\x14\n\x10svc_TempEntities\x10\x1b\x12\x10\n\x0csvc_Prefetch\x10\x1c\x12\x0c\n\x08svc_Menu\x10\x1d\x12\x15\n\x11svc_GameEventList\x10\x1e\x12\x14\n\x10svc_GetCvarValue\x10\x1f\x12\x14\n\x10svc_PaintmapData\x10!\x12\x14\n\x10svc_CmdKeyValues\x10\"\x12\x15\n\x11svc_EncryptedData\x10#\x12\x12\n\x0esvc_HltvReplay\x10$\x12\x19\n\x15svc_Broadcast_Command\x10&*\x87\x01\n\x11ReplayEventType_t\x12\x17\n\x13REPLAY_EVENT_CANCEL\x10\x00\x12\x16\n\x12REPLAY_EVENT_DEATH\x10\x01\x12\x18\n\x14REPLAY_EVENT_GENERIC\x10\x02\x12\'\n#REPLAY_EVENT_STUCK_NEED_FULL_UPDATE\x10\x03\x42\x03\x80\x01\x00')
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_NET_MESSAGES = _descriptor.EnumDescriptor(
  name='NET_Messages',
  full_name='NET_Messages',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='net_NOP', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='net_Disconnect', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='net_File', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='net_SplitScreenUser', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='net_Tick', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='net_StringCmd', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='net_SetConVar', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='net_SignonState', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='net_PlayerAvatarData', index=8, number=100,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=6238,
  serialized_end=6423,
)
_sym_db.RegisterEnumDescriptor(_NET_MESSAGES)

NET_Messages = enum_type_wrapper.EnumTypeWrapper(_NET_MESSAGES)
_CLC_MESSAGES = _descriptor.EnumDescriptor(
  name='CLC_Messages',
  full_name='CLC_Messages',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='clc_ClientInfo', index=0, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='clc_Move', index=1, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='clc_VoiceData', index=2, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='clc_BaselineAck', index=3, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='clc_ListenEvents', index=4, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='clc_RespondCvarValue', index=5, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='clc_FileCRCCheck', index=6, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='clc_LoadingProgress', index=7, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='clc_SplitPlayerConnect', index=8, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='clc_ClientMessage', index=9, number=17,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='clc_CmdKeyValues', index=10, number=18,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='clc_HltvReplay', index=11, number=20,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=6426,
  serialized_end=6702,
)
_sym_db.RegisterEnumDescriptor(_CLC_MESSAGES)

CLC_Messages = enum_type_wrapper.EnumTypeWrapper(_CLC_MESSAGES)
_VOICEDATAFORMAT_T = _descriptor.EnumDescriptor(
  name='VoiceDataFormat_t',
  full_name='VoiceDataFormat_t',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VOICEDATA_FORMAT_STEAM', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VOICEDATA_FORMAT_ENGINE', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=6704,
  serialized_end=6780,
)
_sym_db.RegisterEnumDescriptor(_VOICEDATAFORMAT_T)

VoiceDataFormat_t = enum_type_wrapper.EnumTypeWrapper(_VOICEDATAFORMAT_T)
_ESPLITSCREENMESSAGETYPE = _descriptor.EnumDescriptor(
  name='ESplitScreenMessageType',
  full_name='ESplitScreenMessageType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MSG_SPLITSCREEN_ADDUSER', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MSG_SPLITSCREEN_REMOVEUSER', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MSG_SPLITSCREEN_TYPE_BITS', index=2, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=_descriptor._ParseOptions(descriptor_pb2.EnumOptions(), _b('\020\001')),
  serialized_start=6782,
  serialized_end=6903,
)
_sym_db.RegisterEnumDescriptor(_ESPLITSCREENMESSAGETYPE)

ESplitScreenMessageType = enum_type_wrapper.EnumTypeWrapper(_ESPLITSCREENMESSAGETYPE)
_SVC_MESSAGES = _descriptor.EnumDescriptor(
  name='SVC_Messages',
  full_name='SVC_Messages',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='svc_ServerInfo', index=0, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='svc_SendTable', index=1, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='svc_ClassInfo', index=2, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='svc_SetPause', index=3, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='svc_CreateStringTable', index=4, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='svc_UpdateStringTable', index=5, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='svc_VoiceInit', index=6, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='svc_VoiceData', index=7, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='svc_Print', index=8, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='svc_Sounds', index=9, number=17,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='svc_SetView', index=10, number=18,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='svc_FixAngle', index=11, number=19,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='svc_CrosshairAngle', index=12, number=20,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='svc_BSPDecal', index=13, number=21,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='svc_SplitScreen', index=14, number=22,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='svc_UserMessage', index=15, number=23,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='svc_EntityMessage', index=16, number=24,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='svc_GameEvent', index=17, number=25,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='svc_PacketEntities', index=18, number=26,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='svc_TempEntities', index=19, number=27,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='svc_Prefetch', index=20, number=28,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='svc_Menu', index=21, number=29,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='svc_GameEventList', index=22, number=30,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='svc_GetCvarValue', index=23, number=31,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='svc_PaintmapData', index=24, number=33,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='svc_CmdKeyValues', index=25, number=34,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='svc_EncryptedData', index=26, number=35,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='svc_HltvReplay', index=27, number=36,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='svc_Broadcast_Command', index=28, number=38,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=6906,
  serialized_end=7517,
)
_sym_db.RegisterEnumDescriptor(_SVC_MESSAGES)

SVC_Messages = enum_type_wrapper.EnumTypeWrapper(_SVC_MESSAGES)
_REPLAYEVENTTYPE_T = _descriptor.EnumDescriptor(
  name='ReplayEventType_t',
  full_name='ReplayEventType_t',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REPLAY_EVENT_CANCEL', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REPLAY_EVENT_DEATH', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REPLAY_EVENT_GENERIC', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REPLAY_EVENT_STUCK_NEED_FULL_UPDATE', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=7520,
  serialized_end=7655,
)
_sym_db.RegisterEnumDescriptor(_REPLAYEVENTTYPE_T)

ReplayEventType_t = enum_type_wrapper.EnumTypeWrapper(_REPLAYEVENTTYPE_T)
net_NOP = 0
net_Disconnect = 1
net_File = 2
net_SplitScreenUser = 3
net_Tick = 4
net_StringCmd = 5
net_SetConVar = 6
net_SignonState = 7
net_PlayerAvatarData = 100
clc_ClientInfo = 8
clc_Move = 9
clc_VoiceData = 10
clc_BaselineAck = 11
clc_ListenEvents = 12
clc_RespondCvarValue = 13
clc_FileCRCCheck = 14
clc_LoadingProgress = 15
clc_SplitPlayerConnect = 16
clc_ClientMessage = 17
clc_CmdKeyValues = 18
clc_HltvReplay = 20
VOICEDATA_FORMAT_STEAM = 0
VOICEDATA_FORMAT_ENGINE = 1
MSG_SPLITSCREEN_ADDUSER = 0
MSG_SPLITSCREEN_REMOVEUSER = 1
MSG_SPLITSCREEN_TYPE_BITS = 1
svc_ServerInfo = 8
svc_SendTable = 9
svc_ClassInfo = 10
svc_SetPause = 11
svc_CreateStringTable = 12
svc_UpdateStringTable = 13
svc_VoiceInit = 14
svc_VoiceData = 15
svc_Print = 16
svc_Sounds = 17
svc_SetView = 18
svc_FixAngle = 19
svc_CrosshairAngle = 20
svc_BSPDecal = 21
svc_SplitScreen = 22
svc_UserMessage = 23
svc_EntityMessage = 24
svc_GameEvent = 25
svc_PacketEntities = 26
svc_TempEntities = 27
svc_Prefetch = 28
svc_Menu = 29
svc_GameEventList = 30
svc_GetCvarValue = 31
svc_PaintmapData = 33
svc_CmdKeyValues = 34
svc_EncryptedData = 35
svc_HltvReplay = 36
svc_Broadcast_Command = 38
REPLAY_EVENT_CANCEL = 0
REPLAY_EVENT_DEATH = 1
REPLAY_EVENT_GENERIC = 2
REPLAY_EVENT_STUCK_NEED_FULL_UPDATE = 3



_CMSGVECTOR = _descriptor.Descriptor(
  name='CMsgVector',
  full_name='CMsgVector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='CMsgVector.x', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='y', full_name='CMsgVector.y', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='z', full_name='CMsgVector.z', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=76,
  serialized_end=121,
)


_CMSGVECTOR2D = _descriptor.Descriptor(
  name='CMsgVector2D',
  full_name='CMsgVector2D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='CMsgVector2D.x', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='y', full_name='CMsgVector2D.y', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=123,
  serialized_end=159,
)


_CMSGQANGLE = _descriptor.Descriptor(
  name='CMsgQAngle',
  full_name='CMsgQAngle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='CMsgQAngle.x', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='y', full_name='CMsgQAngle.y', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='z', full_name='CMsgQAngle.z', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=161,
  serialized_end=206,
)


_CMSGRGBA = _descriptor.Descriptor(
  name='CMsgRGBA',
  full_name='CMsgRGBA',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='r', full_name='CMsgRGBA.r', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='g', full_name='CMsgRGBA.g', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='b', full_name='CMsgRGBA.b', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='a', full_name='CMsgRGBA.a', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=208,
  serialized_end=262,
)


_CNETMSG_TICK = _descriptor.Descriptor(
  name='CNETMsg_Tick',
  full_name='CNETMsg_Tick',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tick', full_name='CNETMsg_Tick.tick', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='host_computationtime', full_name='CNETMsg_Tick.host_computationtime', index=1,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='host_computationtime_std_deviation', full_name='CNETMsg_Tick.host_computationtime_std_deviation', index=2,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='host_framestarttime_std_deviation', full_name='CNETMsg_Tick.host_framestarttime_std_deviation', index=3,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hltv_replay_flags', full_name='CNETMsg_Tick.hltv_replay_flags', index=4,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=265,
  serialized_end=437,
)


_CNETMSG_STRINGCMD = _descriptor.Descriptor(
  name='CNETMsg_StringCmd',
  full_name='CNETMsg_StringCmd',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='CNETMsg_StringCmd.command', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=439,
  serialized_end=475,
)


_CNETMSG_SIGNONSTATE = _descriptor.Descriptor(
  name='CNETMsg_SignonState',
  full_name='CNETMsg_SignonState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='signon_state', full_name='CNETMsg_SignonState.signon_state', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='spawn_count', full_name='CNETMsg_SignonState.spawn_count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_server_players', full_name='CNETMsg_SignonState.num_server_players', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='players_networkids', full_name='CNETMsg_SignonState.players_networkids', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='map_name', full_name='CNETMsg_SignonState.map_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=478,
  serialized_end=616,
)


_CMSG_CVARS_CVAR = _descriptor.Descriptor(
  name='CVar',
  full_name='CMsg_CVars.CVar',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsg_CVars.CVar.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='CMsg_CVars.CVar.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dictionary_name', full_name='CMsg_CVars.CVar.dictionary_name', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=665,
  serialized_end=725,
)

_CMSG_CVARS = _descriptor.Descriptor(
  name='CMsg_CVars',
  full_name='CMsg_CVars',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cvars', full_name='CMsg_CVars.cvars', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSG_CVARS_CVAR, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=618,
  serialized_end=725,
)


_CNETMSG_SETCONVAR = _descriptor.Descriptor(
  name='CNETMsg_SetConVar',
  full_name='CNETMsg_SetConVar',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='convars', full_name='CNETMsg_SetConVar.convars', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=727,
  serialized_end=776,
)


_CNETMSG_NOP = _descriptor.Descriptor(
  name='CNETMsg_NOP',
  full_name='CNETMsg_NOP',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=778,
  serialized_end=791,
)


_CNETMSG_DISCONNECT = _descriptor.Descriptor(
  name='CNETMsg_Disconnect',
  full_name='CNETMsg_Disconnect',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='CNETMsg_Disconnect.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=793,
  serialized_end=827,
)


_CNETMSG_FILE = _descriptor.Descriptor(
  name='CNETMsg_File',
  full_name='CNETMsg_File',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transfer_id', full_name='CNETMsg_File.transfer_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='file_name', full_name='CNETMsg_File.file_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_replay_demo_file', full_name='CNETMsg_File.is_replay_demo_file', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='deny', full_name='CNETMsg_File.deny', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=829,
  serialized_end=926,
)


_CNETMSG_SPLITSCREENUSER = _descriptor.Descriptor(
  name='CNETMsg_SplitScreenUser',
  full_name='CNETMsg_SplitScreenUser',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='slot', full_name='CNETMsg_SplitScreenUser.slot', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=928,
  serialized_end=967,
)


_CNETMSG_PLAYERAVATARDATA = _descriptor.Descriptor(
  name='CNETMsg_PlayerAvatarData',
  full_name='CNETMsg_PlayerAvatarData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CNETMsg_PlayerAvatarData.accountid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rgb', full_name='CNETMsg_PlayerAvatarData.rgb', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=969,
  serialized_end=1027,
)


_CCLCMSG_CLIENTINFO = _descriptor.Descriptor(
  name='CCLCMsg_ClientInfo',
  full_name='CCLCMsg_ClientInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='send_table_crc', full_name='CCLCMsg_ClientInfo.send_table_crc', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_count', full_name='CCLCMsg_ClientInfo.server_count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_hltv', full_name='CCLCMsg_ClientInfo.is_hltv', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_replay', full_name='CCLCMsg_ClientInfo.is_replay', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='friends_id', full_name='CCLCMsg_ClientInfo.friends_id', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='friends_name', full_name='CCLCMsg_ClientInfo.friends_name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_files', full_name='CCLCMsg_ClientInfo.custom_files', index=6,
      number=7, type=7, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1030,
  serialized_end=1196,
)


_CCLCMSG_MOVE = _descriptor.Descriptor(
  name='CCLCMsg_Move',
  full_name='CCLCMsg_Move',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_backup_commands', full_name='CCLCMsg_Move.num_backup_commands', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_new_commands', full_name='CCLCMsg_Move.num_new_commands', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='CCLCMsg_Move.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1198,
  serialized_end=1281,
)


_CCLCMSG_VOICEDATA = _descriptor.Descriptor(
  name='CCLCMsg_VoiceData',
  full_name='CCLCMsg_VoiceData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='CCLCMsg_VoiceData.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='xuid', full_name='CCLCMsg_VoiceData.xuid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='format', full_name='CCLCMsg_VoiceData.format', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sequence_bytes', full_name='CCLCMsg_VoiceData.sequence_bytes', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='section_number', full_name='CCLCMsg_VoiceData.section_number', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='uncompressed_sample_offset', full_name='CCLCMsg_VoiceData.uncompressed_sample_offset', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1284,
  serialized_end=1476,
)


_CCLCMSG_BASELINEACK = _descriptor.Descriptor(
  name='CCLCMsg_BaselineAck',
  full_name='CCLCMsg_BaselineAck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='baseline_tick', full_name='CCLCMsg_BaselineAck.baseline_tick', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='baseline_nr', full_name='CCLCMsg_BaselineAck.baseline_nr', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1478,
  serialized_end=1543,
)


_CCLCMSG_LISTENEVENTS = _descriptor.Descriptor(
  name='CCLCMsg_ListenEvents',
  full_name='CCLCMsg_ListenEvents',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_mask', full_name='CCLCMsg_ListenEvents.event_mask', index=0,
      number=1, type=7, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1545,
  serialized_end=1587,
)


_CCLCMSG_RESPONDCVARVALUE = _descriptor.Descriptor(
  name='CCLCMsg_RespondCvarValue',
  full_name='CCLCMsg_RespondCvarValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cookie', full_name='CCLCMsg_RespondCvarValue.cookie', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status_code', full_name='CCLCMsg_RespondCvarValue.status_code', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='CCLCMsg_RespondCvarValue.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='CCLCMsg_RespondCvarValue.value', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1589,
  serialized_end=1681,
)


_CCLCMSG_FILECRCCHECK = _descriptor.Descriptor(
  name='CCLCMsg_FileCRCCheck',
  full_name='CCLCMsg_FileCRCCheck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code_path', full_name='CCLCMsg_FileCRCCheck.code_path', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='path', full_name='CCLCMsg_FileCRCCheck.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='code_filename', full_name='CCLCMsg_FileCRCCheck.code_filename', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filename', full_name='CCLCMsg_FileCRCCheck.filename', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='file_fraction', full_name='CCLCMsg_FileCRCCheck.file_fraction', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='md5', full_name='CCLCMsg_FileCRCCheck.md5', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='crc', full_name='CCLCMsg_FileCRCCheck.crc', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='file_hash_type', full_name='CCLCMsg_FileCRCCheck.file_hash_type', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='file_len', full_name='CCLCMsg_FileCRCCheck.file_len', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pack_file_id', full_name='CCLCMsg_FileCRCCheck.pack_file_id', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pack_file_number', full_name='CCLCMsg_FileCRCCheck.pack_file_number', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1684,
  serialized_end=1919,
)


_CCLCMSG_LOADINGPROGRESS = _descriptor.Descriptor(
  name='CCLCMsg_LoadingProgress',
  full_name='CCLCMsg_LoadingProgress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='progress', full_name='CCLCMsg_LoadingProgress.progress', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1921,
  serialized_end=1964,
)


_CCLCMSG_SPLITPLAYERCONNECT = _descriptor.Descriptor(
  name='CCLCMsg_SplitPlayerConnect',
  full_name='CCLCMsg_SplitPlayerConnect',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='convars', full_name='CCLCMsg_SplitPlayerConnect.convars', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1966,
  serialized_end=2024,
)


_CCLCMSG_CMDKEYVALUES = _descriptor.Descriptor(
  name='CCLCMsg_CmdKeyValues',
  full_name='CCLCMsg_CmdKeyValues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='keyvalues', full_name='CCLCMsg_CmdKeyValues.keyvalues', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2026,
  serialized_end=2067,
)


_CSVCMSG_SERVERINFO = _descriptor.Descriptor(
  name='CSVCMsg_ServerInfo',
  full_name='CSVCMsg_ServerInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='protocol', full_name='CSVCMsg_ServerInfo.protocol', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_count', full_name='CSVCMsg_ServerInfo.server_count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_dedicated', full_name='CSVCMsg_ServerInfo.is_dedicated', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_official_valve_server', full_name='CSVCMsg_ServerInfo.is_official_valve_server', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_hltv', full_name='CSVCMsg_ServerInfo.is_hltv', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_replay', full_name='CSVCMsg_ServerInfo.is_replay', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_redirecting_to_proxy_relay', full_name='CSVCMsg_ServerInfo.is_redirecting_to_proxy_relay', index=6,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='c_os', full_name='CSVCMsg_ServerInfo.c_os', index=7,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='map_crc', full_name='CSVCMsg_ServerInfo.map_crc', index=8,
      number=8, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_crc', full_name='CSVCMsg_ServerInfo.client_crc', index=9,
      number=9, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='string_table_crc', full_name='CSVCMsg_ServerInfo.string_table_crc', index=10,
      number=10, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_clients', full_name='CSVCMsg_ServerInfo.max_clients', index=11,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_classes', full_name='CSVCMsg_ServerInfo.max_classes', index=12,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_slot', full_name='CSVCMsg_ServerInfo.player_slot', index=13,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tick_interval', full_name='CSVCMsg_ServerInfo.tick_interval', index=14,
      number=14, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_dir', full_name='CSVCMsg_ServerInfo.game_dir', index=15,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='map_name', full_name='CSVCMsg_ServerInfo.map_name', index=16,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='map_group_name', full_name='CSVCMsg_ServerInfo.map_group_name', index=17,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sky_name', full_name='CSVCMsg_ServerInfo.sky_name', index=18,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='host_name', full_name='CSVCMsg_ServerInfo.host_name', index=19,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='public_ip', full_name='CSVCMsg_ServerInfo.public_ip', index=20,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ugc_map_id', full_name='CSVCMsg_ServerInfo.ugc_map_id', index=21,
      number=22, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2070,
  serialized_end=2560,
)


_CSVCMSG_CLASSINFO_CLASS_T = _descriptor.Descriptor(
  name='class_t',
  full_name='CSVCMsg_ClassInfo.class_t',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='class_id', full_name='CSVCMsg_ClassInfo.class_t.class_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data_table_name', full_name='CSVCMsg_ClassInfo.class_t.data_table_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='class_name', full_name='CSVCMsg_ClassInfo.class_t.class_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2655,
  serialized_end=2727,
)

_CSVCMSG_CLASSINFO = _descriptor.Descriptor(
  name='CSVCMsg_ClassInfo',
  full_name='CSVCMsg_ClassInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='create_on_client', full_name='CSVCMsg_ClassInfo.create_on_client', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='classes', full_name='CSVCMsg_ClassInfo.classes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CSVCMSG_CLASSINFO_CLASS_T, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2563,
  serialized_end=2727,
)


_CSVCMSG_SENDTABLE_SENDPROP_T = _descriptor.Descriptor(
  name='sendprop_t',
  full_name='CSVCMsg_SendTable.sendprop_t',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='CSVCMsg_SendTable.sendprop_t.type', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='var_name', full_name='CSVCMsg_SendTable.sendprop_t.var_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='flags', full_name='CSVCMsg_SendTable.sendprop_t.flags', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='priority', full_name='CSVCMsg_SendTable.sendprop_t.priority', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dt_name', full_name='CSVCMsg_SendTable.sendprop_t.dt_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_elements', full_name='CSVCMsg_SendTable.sendprop_t.num_elements', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='low_value', full_name='CSVCMsg_SendTable.sendprop_t.low_value', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='high_value', full_name='CSVCMsg_SendTable.sendprop_t.high_value', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_bits', full_name='CSVCMsg_SendTable.sendprop_t.num_bits', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2861,
  serialized_end=3034,
)

_CSVCMSG_SENDTABLE = _descriptor.Descriptor(
  name='CSVCMsg_SendTable',
  full_name='CSVCMsg_SendTable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_end', full_name='CSVCMsg_SendTable.is_end', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='net_table_name', full_name='CSVCMsg_SendTable.net_table_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='needs_decoder', full_name='CSVCMsg_SendTable.needs_decoder', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='props', full_name='CSVCMsg_SendTable.props', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CSVCMSG_SENDTABLE_SENDPROP_T, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2730,
  serialized_end=3034,
)


_CSVCMSG_PRINT = _descriptor.Descriptor(
  name='CSVCMsg_Print',
  full_name='CSVCMsg_Print',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='CSVCMsg_Print.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3036,
  serialized_end=3065,
)


_CSVCMSG_SETPAUSE = _descriptor.Descriptor(
  name='CSVCMsg_SetPause',
  full_name='CSVCMsg_SetPause',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='paused', full_name='CSVCMsg_SetPause.paused', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3067,
  serialized_end=3101,
)


_CSVCMSG_SETVIEW = _descriptor.Descriptor(
  name='CSVCMsg_SetView',
  full_name='CSVCMsg_SetView',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entity_index', full_name='CSVCMsg_SetView.entity_index', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3103,
  serialized_end=3142,
)


_CSVCMSG_CREATESTRINGTABLE = _descriptor.Descriptor(
  name='CSVCMsg_CreateStringTable',
  full_name='CSVCMsg_CreateStringTable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='CSVCMsg_CreateStringTable.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_entries', full_name='CSVCMsg_CreateStringTable.max_entries', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_entries', full_name='CSVCMsg_CreateStringTable.num_entries', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_data_fixed_size', full_name='CSVCMsg_CreateStringTable.user_data_fixed_size', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_data_size', full_name='CSVCMsg_CreateStringTable.user_data_size', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_data_size_bits', full_name='CSVCMsg_CreateStringTable.user_data_size_bits', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='flags', full_name='CSVCMsg_CreateStringTable.flags', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='string_data', full_name='CSVCMsg_CreateStringTable.string_data', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3145,
  serialized_end=3347,
)


_CSVCMSG_UPDATESTRINGTABLE = _descriptor.Descriptor(
  name='CSVCMsg_UpdateStringTable',
  full_name='CSVCMsg_UpdateStringTable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='table_id', full_name='CSVCMsg_UpdateStringTable.table_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_changed_entries', full_name='CSVCMsg_UpdateStringTable.num_changed_entries', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='string_data', full_name='CSVCMsg_UpdateStringTable.string_data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3349,
  serialized_end=3444,
)


_CSVCMSG_VOICEINIT = _descriptor.Descriptor(
  name='CSVCMsg_VoiceInit',
  full_name='CSVCMsg_VoiceInit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='quality', full_name='CSVCMsg_VoiceInit.quality', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='codec', full_name='CSVCMsg_VoiceInit.codec', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='version', full_name='CSVCMsg_VoiceInit.version', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3446,
  serialized_end=3517,
)


_CSVCMSG_VOICEDATA = _descriptor.Descriptor(
  name='CSVCMsg_VoiceData',
  full_name='CSVCMsg_VoiceData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client', full_name='CSVCMsg_VoiceData.client', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='proximity', full_name='CSVCMsg_VoiceData.proximity', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='xuid', full_name='CSVCMsg_VoiceData.xuid', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='audible_mask', full_name='CSVCMsg_VoiceData.audible_mask', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='voice_data', full_name='CSVCMsg_VoiceData.voice_data', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='caster', full_name='CSVCMsg_VoiceData.caster', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='format', full_name='CSVCMsg_VoiceData.format', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sequence_bytes', full_name='CSVCMsg_VoiceData.sequence_bytes', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='section_number', full_name='CSVCMsg_VoiceData.section_number', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='uncompressed_sample_offset', full_name='CSVCMsg_VoiceData.uncompressed_sample_offset', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3520,
  serialized_end=3791,
)


_CSVCMSG_FIXANGLE = _descriptor.Descriptor(
  name='CSVCMsg_FixAngle',
  full_name='CSVCMsg_FixAngle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='relative', full_name='CSVCMsg_FixAngle.relative', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='angle', full_name='CSVCMsg_FixAngle.angle', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3793,
  serialized_end=3857,
)


_CSVCMSG_CROSSHAIRANGLE = _descriptor.Descriptor(
  name='CSVCMsg_CrosshairAngle',
  full_name='CSVCMsg_CrosshairAngle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='angle', full_name='CSVCMsg_CrosshairAngle.angle', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3859,
  serialized_end=3911,
)


_CSVCMSG_PREFETCH = _descriptor.Descriptor(
  name='CSVCMsg_Prefetch',
  full_name='CSVCMsg_Prefetch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sound_index', full_name='CSVCMsg_Prefetch.sound_index', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3913,
  serialized_end=3952,
)


_CSVCMSG_BSPDECAL = _descriptor.Descriptor(
  name='CSVCMsg_BSPDecal',
  full_name='CSVCMsg_BSPDecal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pos', full_name='CSVCMsg_BSPDecal.pos', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='decal_texture_index', full_name='CSVCMsg_BSPDecal.decal_texture_index', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='entity_index', full_name='CSVCMsg_BSPDecal.entity_index', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='model_index', full_name='CSVCMsg_BSPDecal.model_index', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='low_priority', full_name='CSVCMsg_BSPDecal.low_priority', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3955,
  serialized_end=4093,
)


_CSVCMSG_SPLITSCREEN = _descriptor.Descriptor(
  name='CSVCMsg_SplitScreen',
  full_name='CSVCMsg_SplitScreen',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='CSVCMsg_SplitScreen.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='slot', full_name='CSVCMsg_SplitScreen.slot', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_index', full_name='CSVCMsg_SplitScreen.player_index', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4095,
  serialized_end=4217,
)


_CSVCMSG_GETCVARVALUE = _descriptor.Descriptor(
  name='CSVCMsg_GetCvarValue',
  full_name='CSVCMsg_GetCvarValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cookie', full_name='CSVCMsg_GetCvarValue.cookie', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cvar_name', full_name='CSVCMsg_GetCvarValue.cvar_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4219,
  serialized_end=4276,
)


_CSVCMSG_MENU = _descriptor.Descriptor(
  name='CSVCMsg_Menu',
  full_name='CSVCMsg_Menu',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dialog_type', full_name='CSVCMsg_Menu.dialog_type', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='menu_key_values', full_name='CSVCMsg_Menu.menu_key_values', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4278,
  serialized_end=4338,
)


_CSVCMSG_USERMESSAGE = _descriptor.Descriptor(
  name='CSVCMsg_UserMessage',
  full_name='CSVCMsg_UserMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='msg_type', full_name='CSVCMsg_UserMessage.msg_type', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='msg_data', full_name='CSVCMsg_UserMessage.msg_data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='passthrough', full_name='CSVCMsg_UserMessage.passthrough', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4340,
  serialized_end=4418,
)


_CSVCMSG_PAINTMAPDATA = _descriptor.Descriptor(
  name='CSVCMsg_PaintmapData',
  full_name='CSVCMsg_PaintmapData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='paintmap', full_name='CSVCMsg_PaintmapData.paintmap', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4420,
  serialized_end=4460,
)


_CSVCMSG_GAMEEVENT_KEY_T = _descriptor.Descriptor(
  name='key_t',
  full_name='CSVCMsg_GameEvent.key_t',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='CSVCMsg_GameEvent.key_t.type', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='val_string', full_name='CSVCMsg_GameEvent.key_t.val_string', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='val_float', full_name='CSVCMsg_GameEvent.key_t.val_float', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='val_long', full_name='CSVCMsg_GameEvent.key_t.val_long', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='val_short', full_name='CSVCMsg_GameEvent.key_t.val_short', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='val_byte', full_name='CSVCMsg_GameEvent.key_t.val_byte', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='val_bool', full_name='CSVCMsg_GameEvent.key_t.val_bool', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='val_uint64', full_name='CSVCMsg_GameEvent.key_t.val_uint64', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='val_wstring', full_name='CSVCMsg_GameEvent.key_t.val_wstring', index=8,
      number=9, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4583,
  serialized_end=4757,
)

_CSVCMSG_GAMEEVENT = _descriptor.Descriptor(
  name='CSVCMsg_GameEvent',
  full_name='CSVCMsg_GameEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_name', full_name='CSVCMsg_GameEvent.event_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='eventid', full_name='CSVCMsg_GameEvent.eventid', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='keys', full_name='CSVCMsg_GameEvent.keys', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='passthrough', full_name='CSVCMsg_GameEvent.passthrough', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CSVCMSG_GAMEEVENT_KEY_T, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4463,
  serialized_end=4757,
)


_CSVCMSG_GAMEEVENTLIST_KEY_T = _descriptor.Descriptor(
  name='key_t',
  full_name='CSVCMsg_GameEventList.key_t',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='CSVCMsg_GameEventList.key_t.type', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='CSVCMsg_GameEventList.key_t.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4843,
  serialized_end=4878,
)

_CSVCMSG_GAMEEVENTLIST_DESCRIPTOR_T = _descriptor.Descriptor(
  name='descriptor_t',
  full_name='CSVCMsg_GameEventList.descriptor_t',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eventid', full_name='CSVCMsg_GameEventList.descriptor_t.eventid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='CSVCMsg_GameEventList.descriptor_t.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='keys', full_name='CSVCMsg_GameEventList.descriptor_t.keys', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4880,
  serialized_end=4969,
)

_CSVCMSG_GAMEEVENTLIST = _descriptor.Descriptor(
  name='CSVCMsg_GameEventList',
  full_name='CSVCMsg_GameEventList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='descriptors', full_name='CSVCMsg_GameEventList.descriptors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CSVCMSG_GAMEEVENTLIST_KEY_T, _CSVCMSG_GAMEEVENTLIST_DESCRIPTOR_T, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4760,
  serialized_end=4969,
)


_CSVCMSG_TEMPENTITIES = _descriptor.Descriptor(
  name='CSVCMsg_TempEntities',
  full_name='CSVCMsg_TempEntities',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='reliable', full_name='CSVCMsg_TempEntities.reliable', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_entries', full_name='CSVCMsg_TempEntities.num_entries', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='entity_data', full_name='CSVCMsg_TempEntities.entity_data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4971,
  serialized_end=5053,
)


_CSVCMSG_PACKETENTITIES = _descriptor.Descriptor(
  name='CSVCMsg_PacketEntities',
  full_name='CSVCMsg_PacketEntities',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_entries', full_name='CSVCMsg_PacketEntities.max_entries', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='updated_entries', full_name='CSVCMsg_PacketEntities.updated_entries', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_delta', full_name='CSVCMsg_PacketEntities.is_delta', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='update_baseline', full_name='CSVCMsg_PacketEntities.update_baseline', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='baseline', full_name='CSVCMsg_PacketEntities.baseline', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='delta_from', full_name='CSVCMsg_PacketEntities.delta_from', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='entity_data', full_name='CSVCMsg_PacketEntities.entity_data', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5056,
  serialized_end=5228,
)


_CSVCMSG_SOUNDS_SOUNDDATA_T = _descriptor.Descriptor(
  name='sounddata_t',
  full_name='CSVCMsg_Sounds.sounddata_t',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='origin_x', full_name='CSVCMsg_Sounds.sounddata_t.origin_x', index=0,
      number=1, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='origin_y', full_name='CSVCMsg_Sounds.sounddata_t.origin_y', index=1,
      number=2, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='origin_z', full_name='CSVCMsg_Sounds.sounddata_t.origin_z', index=2,
      number=3, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='volume', full_name='CSVCMsg_Sounds.sounddata_t.volume', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='delay_value', full_name='CSVCMsg_Sounds.sounddata_t.delay_value', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sequence_number', full_name='CSVCMsg_Sounds.sounddata_t.sequence_number', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='entity_index', full_name='CSVCMsg_Sounds.sounddata_t.entity_index', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channel', full_name='CSVCMsg_Sounds.sounddata_t.channel', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pitch', full_name='CSVCMsg_Sounds.sounddata_t.pitch', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='flags', full_name='CSVCMsg_Sounds.sounddata_t.flags', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sound_num', full_name='CSVCMsg_Sounds.sounddata_t.sound_num', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sound_num_handle', full_name='CSVCMsg_Sounds.sounddata_t.sound_num_handle', index=11,
      number=12, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='speaker_entity', full_name='CSVCMsg_Sounds.sounddata_t.speaker_entity', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='random_seed', full_name='CSVCMsg_Sounds.sounddata_t.random_seed', index=13,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sound_level', full_name='CSVCMsg_Sounds.sounddata_t.sound_level', index=14,
      number=15, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_sentence', full_name='CSVCMsg_Sounds.sounddata_t.is_sentence', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_ambient', full_name='CSVCMsg_Sounds.sounddata_t.is_ambient', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5319,
  serialized_end=5669,
)

_CSVCMSG_SOUNDS = _descriptor.Descriptor(
  name='CSVCMsg_Sounds',
  full_name='CSVCMsg_Sounds',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='reliable_sound', full_name='CSVCMsg_Sounds.reliable_sound', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sounds', full_name='CSVCMsg_Sounds.sounds', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CSVCMSG_SOUNDS_SOUNDDATA_T, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5231,
  serialized_end=5669,
)


_CSVCMSG_ENTITYMSG = _descriptor.Descriptor(
  name='CSVCMsg_EntityMsg',
  full_name='CSVCMsg_EntityMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ent_index', full_name='CSVCMsg_EntityMsg.ent_index', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='class_id', full_name='CSVCMsg_EntityMsg.class_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ent_data', full_name='CSVCMsg_EntityMsg.ent_data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5671,
  serialized_end=5745,
)


_CSVCMSG_CMDKEYVALUES = _descriptor.Descriptor(
  name='CSVCMsg_CmdKeyValues',
  full_name='CSVCMsg_CmdKeyValues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='keyvalues', full_name='CSVCMsg_CmdKeyValues.keyvalues', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5747,
  serialized_end=5788,
)


_CSVCMSG_ENCRYPTEDDATA = _descriptor.Descriptor(
  name='CSVCMsg_EncryptedData',
  full_name='CSVCMsg_EncryptedData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='encrypted', full_name='CSVCMsg_EncryptedData.encrypted', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='key_type', full_name='CSVCMsg_EncryptedData.key_type', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5790,
  serialized_end=5850,
)


_CSVCMSG_HLTVREPLAY = _descriptor.Descriptor(
  name='CSVCMsg_HltvReplay',
  full_name='CSVCMsg_HltvReplay',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='delay', full_name='CSVCMsg_HltvReplay.delay', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='primary_target', full_name='CSVCMsg_HltvReplay.primary_target', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='replay_stop_at', full_name='CSVCMsg_HltvReplay.replay_stop_at', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='replay_start_at', full_name='CSVCMsg_HltvReplay.replay_start_at', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='replay_slowdown_begin', full_name='CSVCMsg_HltvReplay.replay_slowdown_begin', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='replay_slowdown_end', full_name='CSVCMsg_HltvReplay.replay_slowdown_end', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='replay_slowdown_rate', full_name='CSVCMsg_HltvReplay.replay_slowdown_rate', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5853,
  serialized_end=6051,
)


_CCLCMSG_HLTVREPLAY = _descriptor.Descriptor(
  name='CCLCMsg_HltvReplay',
  full_name='CCLCMsg_HltvReplay',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='CCLCMsg_HltvReplay.request', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='slowdown_length', full_name='CCLCMsg_HltvReplay.slowdown_length', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='slowdown_rate', full_name='CCLCMsg_HltvReplay.slowdown_rate', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='primary_target_ent_index', full_name='CCLCMsg_HltvReplay.primary_target_ent_index', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='event_time', full_name='CCLCMsg_HltvReplay.event_time', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6054,
  serialized_end=6193,
)


_CSVCMSG_BROADCAST_COMMAND = _descriptor.Descriptor(
  name='CSVCMsg_Broadcast_Command',
  full_name='CSVCMsg_Broadcast_Command',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cmd', full_name='CSVCMsg_Broadcast_Command.cmd', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6195,
  serialized_end=6235,
)

_CMSG_CVARS_CVAR.containing_type = _CMSG_CVARS
_CMSG_CVARS.fields_by_name['cvars'].message_type = _CMSG_CVARS_CVAR
_CNETMSG_SETCONVAR.fields_by_name['convars'].message_type = _CMSG_CVARS
_CCLCMSG_VOICEDATA.fields_by_name['format'].enum_type = _VOICEDATAFORMAT_T
_CCLCMSG_SPLITPLAYERCONNECT.fields_by_name['convars'].message_type = _CMSG_CVARS
_CSVCMSG_CLASSINFO_CLASS_T.containing_type = _CSVCMSG_CLASSINFO
_CSVCMSG_CLASSINFO.fields_by_name['classes'].message_type = _CSVCMSG_CLASSINFO_CLASS_T
_CSVCMSG_SENDTABLE_SENDPROP_T.containing_type = _CSVCMSG_SENDTABLE
_CSVCMSG_SENDTABLE.fields_by_name['props'].message_type = _CSVCMSG_SENDTABLE_SENDPROP_T
_CSVCMSG_VOICEDATA.fields_by_name['format'].enum_type = _VOICEDATAFORMAT_T
_CSVCMSG_FIXANGLE.fields_by_name['angle'].message_type = _CMSGQANGLE
_CSVCMSG_CROSSHAIRANGLE.fields_by_name['angle'].message_type = _CMSGQANGLE
_CSVCMSG_BSPDECAL.fields_by_name['pos'].message_type = _CMSGVECTOR
_CSVCMSG_SPLITSCREEN.fields_by_name['type'].enum_type = _ESPLITSCREENMESSAGETYPE
_CSVCMSG_GAMEEVENT_KEY_T.containing_type = _CSVCMSG_GAMEEVENT
_CSVCMSG_GAMEEVENT.fields_by_name['keys'].message_type = _CSVCMSG_GAMEEVENT_KEY_T
_CSVCMSG_GAMEEVENTLIST_KEY_T.containing_type = _CSVCMSG_GAMEEVENTLIST
_CSVCMSG_GAMEEVENTLIST_DESCRIPTOR_T.fields_by_name['keys'].message_type = _CSVCMSG_GAMEEVENTLIST_KEY_T
_CSVCMSG_GAMEEVENTLIST_DESCRIPTOR_T.containing_type = _CSVCMSG_GAMEEVENTLIST
_CSVCMSG_GAMEEVENTLIST.fields_by_name['descriptors'].message_type = _CSVCMSG_GAMEEVENTLIST_DESCRIPTOR_T
_CSVCMSG_SOUNDS_SOUNDDATA_T.containing_type = _CSVCMSG_SOUNDS
_CSVCMSG_SOUNDS.fields_by_name['sounds'].message_type = _CSVCMSG_SOUNDS_SOUNDDATA_T
DESCRIPTOR.message_types_by_name['CMsgVector'] = _CMSGVECTOR
DESCRIPTOR.message_types_by_name['CMsgVector2D'] = _CMSGVECTOR2D
DESCRIPTOR.message_types_by_name['CMsgQAngle'] = _CMSGQANGLE
DESCRIPTOR.message_types_by_name['CMsgRGBA'] = _CMSGRGBA
DESCRIPTOR.message_types_by_name['CNETMsg_Tick'] = _CNETMSG_TICK
DESCRIPTOR.message_types_by_name['CNETMsg_StringCmd'] = _CNETMSG_STRINGCMD
DESCRIPTOR.message_types_by_name['CNETMsg_SignonState'] = _CNETMSG_SIGNONSTATE
DESCRIPTOR.message_types_by_name['CMsg_CVars'] = _CMSG_CVARS
DESCRIPTOR.message_types_by_name['CNETMsg_SetConVar'] = _CNETMSG_SETCONVAR
DESCRIPTOR.message_types_by_name['CNETMsg_NOP'] = _CNETMSG_NOP
DESCRIPTOR.message_types_by_name['CNETMsg_Disconnect'] = _CNETMSG_DISCONNECT
DESCRIPTOR.message_types_by_name['CNETMsg_File'] = _CNETMSG_FILE
DESCRIPTOR.message_types_by_name['CNETMsg_SplitScreenUser'] = _CNETMSG_SPLITSCREENUSER
DESCRIPTOR.message_types_by_name['CNETMsg_PlayerAvatarData'] = _CNETMSG_PLAYERAVATARDATA
DESCRIPTOR.message_types_by_name['CCLCMsg_ClientInfo'] = _CCLCMSG_CLIENTINFO
DESCRIPTOR.message_types_by_name['CCLCMsg_Move'] = _CCLCMSG_MOVE
DESCRIPTOR.message_types_by_name['CCLCMsg_VoiceData'] = _CCLCMSG_VOICEDATA
DESCRIPTOR.message_types_by_name['CCLCMsg_BaselineAck'] = _CCLCMSG_BASELINEACK
DESCRIPTOR.message_types_by_name['CCLCMsg_ListenEvents'] = _CCLCMSG_LISTENEVENTS
DESCRIPTOR.message_types_by_name['CCLCMsg_RespondCvarValue'] = _CCLCMSG_RESPONDCVARVALUE
DESCRIPTOR.message_types_by_name['CCLCMsg_FileCRCCheck'] = _CCLCMSG_FILECRCCHECK
DESCRIPTOR.message_types_by_name['CCLCMsg_LoadingProgress'] = _CCLCMSG_LOADINGPROGRESS
DESCRIPTOR.message_types_by_name['CCLCMsg_SplitPlayerConnect'] = _CCLCMSG_SPLITPLAYERCONNECT
DESCRIPTOR.message_types_by_name['CCLCMsg_CmdKeyValues'] = _CCLCMSG_CMDKEYVALUES
DESCRIPTOR.message_types_by_name['CSVCMsg_ServerInfo'] = _CSVCMSG_SERVERINFO
DESCRIPTOR.message_types_by_name['CSVCMsg_ClassInfo'] = _CSVCMSG_CLASSINFO
DESCRIPTOR.message_types_by_name['CSVCMsg_SendTable'] = _CSVCMSG_SENDTABLE
DESCRIPTOR.message_types_by_name['CSVCMsg_Print'] = _CSVCMSG_PRINT
DESCRIPTOR.message_types_by_name['CSVCMsg_SetPause'] = _CSVCMSG_SETPAUSE
DESCRIPTOR.message_types_by_name['CSVCMsg_SetView'] = _CSVCMSG_SETVIEW
DESCRIPTOR.message_types_by_name['CSVCMsg_CreateStringTable'] = _CSVCMSG_CREATESTRINGTABLE
DESCRIPTOR.message_types_by_name['CSVCMsg_UpdateStringTable'] = _CSVCMSG_UPDATESTRINGTABLE
DESCRIPTOR.message_types_by_name['CSVCMsg_VoiceInit'] = _CSVCMSG_VOICEINIT
DESCRIPTOR.message_types_by_name['CSVCMsg_VoiceData'] = _CSVCMSG_VOICEDATA
DESCRIPTOR.message_types_by_name['CSVCMsg_FixAngle'] = _CSVCMSG_FIXANGLE
DESCRIPTOR.message_types_by_name['CSVCMsg_CrosshairAngle'] = _CSVCMSG_CROSSHAIRANGLE
DESCRIPTOR.message_types_by_name['CSVCMsg_Prefetch'] = _CSVCMSG_PREFETCH
DESCRIPTOR.message_types_by_name['CSVCMsg_BSPDecal'] = _CSVCMSG_BSPDECAL
DESCRIPTOR.message_types_by_name['CSVCMsg_SplitScreen'] = _CSVCMSG_SPLITSCREEN
DESCRIPTOR.message_types_by_name['CSVCMsg_GetCvarValue'] = _CSVCMSG_GETCVARVALUE
DESCRIPTOR.message_types_by_name['CSVCMsg_Menu'] = _CSVCMSG_MENU
DESCRIPTOR.message_types_by_name['CSVCMsg_UserMessage'] = _CSVCMSG_USERMESSAGE
DESCRIPTOR.message_types_by_name['CSVCMsg_PaintmapData'] = _CSVCMSG_PAINTMAPDATA
DESCRIPTOR.message_types_by_name['CSVCMsg_GameEvent'] = _CSVCMSG_GAMEEVENT
DESCRIPTOR.message_types_by_name['CSVCMsg_GameEventList'] = _CSVCMSG_GAMEEVENTLIST
DESCRIPTOR.message_types_by_name['CSVCMsg_TempEntities'] = _CSVCMSG_TEMPENTITIES
DESCRIPTOR.message_types_by_name['CSVCMsg_PacketEntities'] = _CSVCMSG_PACKETENTITIES
DESCRIPTOR.message_types_by_name['CSVCMsg_Sounds'] = _CSVCMSG_SOUNDS
DESCRIPTOR.message_types_by_name['CSVCMsg_EntityMsg'] = _CSVCMSG_ENTITYMSG
DESCRIPTOR.message_types_by_name['CSVCMsg_CmdKeyValues'] = _CSVCMSG_CMDKEYVALUES
DESCRIPTOR.message_types_by_name['CSVCMsg_EncryptedData'] = _CSVCMSG_ENCRYPTEDDATA
DESCRIPTOR.message_types_by_name['CSVCMsg_HltvReplay'] = _CSVCMSG_HLTVREPLAY
DESCRIPTOR.message_types_by_name['CCLCMsg_HltvReplay'] = _CCLCMSG_HLTVREPLAY
DESCRIPTOR.message_types_by_name['CSVCMsg_Broadcast_Command'] = _CSVCMSG_BROADCAST_COMMAND
DESCRIPTOR.enum_types_by_name['NET_Messages'] = _NET_MESSAGES
DESCRIPTOR.enum_types_by_name['CLC_Messages'] = _CLC_MESSAGES
DESCRIPTOR.enum_types_by_name['VoiceDataFormat_t'] = _VOICEDATAFORMAT_T
DESCRIPTOR.enum_types_by_name['ESplitScreenMessageType'] = _ESPLITSCREENMESSAGETYPE
DESCRIPTOR.enum_types_by_name['SVC_Messages'] = _SVC_MESSAGES
DESCRIPTOR.enum_types_by_name['ReplayEventType_t'] = _REPLAYEVENTTYPE_T

CMsgVector = _reflection.GeneratedProtocolMessageType('CMsgVector', (_message.Message,), dict(
  DESCRIPTOR = _CMSGVECTOR,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgVector)
  ))
_sym_db.RegisterMessage(CMsgVector)

CMsgVector2D = _reflection.GeneratedProtocolMessageType('CMsgVector2D', (_message.Message,), dict(
  DESCRIPTOR = _CMSGVECTOR2D,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgVector2D)
  ))
_sym_db.RegisterMessage(CMsgVector2D)

CMsgQAngle = _reflection.GeneratedProtocolMessageType('CMsgQAngle', (_message.Message,), dict(
  DESCRIPTOR = _CMSGQANGLE,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgQAngle)
  ))
_sym_db.RegisterMessage(CMsgQAngle)

CMsgRGBA = _reflection.GeneratedProtocolMessageType('CMsgRGBA', (_message.Message,), dict(
  DESCRIPTOR = _CMSGRGBA,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgRGBA)
  ))
_sym_db.RegisterMessage(CMsgRGBA)

CNETMsg_Tick = _reflection.GeneratedProtocolMessageType('CNETMsg_Tick', (_message.Message,), dict(
  DESCRIPTOR = _CNETMSG_TICK,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CNETMsg_Tick)
  ))
_sym_db.RegisterMessage(CNETMsg_Tick)

CNETMsg_StringCmd = _reflection.GeneratedProtocolMessageType('CNETMsg_StringCmd', (_message.Message,), dict(
  DESCRIPTOR = _CNETMSG_STRINGCMD,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CNETMsg_StringCmd)
  ))
_sym_db.RegisterMessage(CNETMsg_StringCmd)

CNETMsg_SignonState = _reflection.GeneratedProtocolMessageType('CNETMsg_SignonState', (_message.Message,), dict(
  DESCRIPTOR = _CNETMSG_SIGNONSTATE,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CNETMsg_SignonState)
  ))
_sym_db.RegisterMessage(CNETMsg_SignonState)

CMsg_CVars = _reflection.GeneratedProtocolMessageType('CMsg_CVars', (_message.Message,), dict(

  CVar = _reflection.GeneratedProtocolMessageType('CVar', (_message.Message,), dict(
    DESCRIPTOR = _CMSG_CVARS_CVAR,
    __module__ = 'demoparser.protobufs.netmessages_pb2'
    # @@protoc_insertion_point(class_scope:CMsg_CVars.CVar)
    ))
  ,
  DESCRIPTOR = _CMSG_CVARS,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsg_CVars)
  ))
_sym_db.RegisterMessage(CMsg_CVars)
_sym_db.RegisterMessage(CMsg_CVars.CVar)

CNETMsg_SetConVar = _reflection.GeneratedProtocolMessageType('CNETMsg_SetConVar', (_message.Message,), dict(
  DESCRIPTOR = _CNETMSG_SETCONVAR,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CNETMsg_SetConVar)
  ))
_sym_db.RegisterMessage(CNETMsg_SetConVar)

CNETMsg_NOP = _reflection.GeneratedProtocolMessageType('CNETMsg_NOP', (_message.Message,), dict(
  DESCRIPTOR = _CNETMSG_NOP,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CNETMsg_NOP)
  ))
_sym_db.RegisterMessage(CNETMsg_NOP)

CNETMsg_Disconnect = _reflection.GeneratedProtocolMessageType('CNETMsg_Disconnect', (_message.Message,), dict(
  DESCRIPTOR = _CNETMSG_DISCONNECT,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CNETMsg_Disconnect)
  ))
_sym_db.RegisterMessage(CNETMsg_Disconnect)

CNETMsg_File = _reflection.GeneratedProtocolMessageType('CNETMsg_File', (_message.Message,), dict(
  DESCRIPTOR = _CNETMSG_FILE,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CNETMsg_File)
  ))
_sym_db.RegisterMessage(CNETMsg_File)

CNETMsg_SplitScreenUser = _reflection.GeneratedProtocolMessageType('CNETMsg_SplitScreenUser', (_message.Message,), dict(
  DESCRIPTOR = _CNETMSG_SPLITSCREENUSER,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CNETMsg_SplitScreenUser)
  ))
_sym_db.RegisterMessage(CNETMsg_SplitScreenUser)

CNETMsg_PlayerAvatarData = _reflection.GeneratedProtocolMessageType('CNETMsg_PlayerAvatarData', (_message.Message,), dict(
  DESCRIPTOR = _CNETMSG_PLAYERAVATARDATA,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CNETMsg_PlayerAvatarData)
  ))
_sym_db.RegisterMessage(CNETMsg_PlayerAvatarData)

CCLCMsg_ClientInfo = _reflection.GeneratedProtocolMessageType('CCLCMsg_ClientInfo', (_message.Message,), dict(
  DESCRIPTOR = _CCLCMSG_CLIENTINFO,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CCLCMsg_ClientInfo)
  ))
_sym_db.RegisterMessage(CCLCMsg_ClientInfo)

CCLCMsg_Move = _reflection.GeneratedProtocolMessageType('CCLCMsg_Move', (_message.Message,), dict(
  DESCRIPTOR = _CCLCMSG_MOVE,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CCLCMsg_Move)
  ))
_sym_db.RegisterMessage(CCLCMsg_Move)

CCLCMsg_VoiceData = _reflection.GeneratedProtocolMessageType('CCLCMsg_VoiceData', (_message.Message,), dict(
  DESCRIPTOR = _CCLCMSG_VOICEDATA,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CCLCMsg_VoiceData)
  ))
_sym_db.RegisterMessage(CCLCMsg_VoiceData)

CCLCMsg_BaselineAck = _reflection.GeneratedProtocolMessageType('CCLCMsg_BaselineAck', (_message.Message,), dict(
  DESCRIPTOR = _CCLCMSG_BASELINEACK,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CCLCMsg_BaselineAck)
  ))
_sym_db.RegisterMessage(CCLCMsg_BaselineAck)

CCLCMsg_ListenEvents = _reflection.GeneratedProtocolMessageType('CCLCMsg_ListenEvents', (_message.Message,), dict(
  DESCRIPTOR = _CCLCMSG_LISTENEVENTS,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CCLCMsg_ListenEvents)
  ))
_sym_db.RegisterMessage(CCLCMsg_ListenEvents)

CCLCMsg_RespondCvarValue = _reflection.GeneratedProtocolMessageType('CCLCMsg_RespondCvarValue', (_message.Message,), dict(
  DESCRIPTOR = _CCLCMSG_RESPONDCVARVALUE,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CCLCMsg_RespondCvarValue)
  ))
_sym_db.RegisterMessage(CCLCMsg_RespondCvarValue)

CCLCMsg_FileCRCCheck = _reflection.GeneratedProtocolMessageType('CCLCMsg_FileCRCCheck', (_message.Message,), dict(
  DESCRIPTOR = _CCLCMSG_FILECRCCHECK,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CCLCMsg_FileCRCCheck)
  ))
_sym_db.RegisterMessage(CCLCMsg_FileCRCCheck)

CCLCMsg_LoadingProgress = _reflection.GeneratedProtocolMessageType('CCLCMsg_LoadingProgress', (_message.Message,), dict(
  DESCRIPTOR = _CCLCMSG_LOADINGPROGRESS,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CCLCMsg_LoadingProgress)
  ))
_sym_db.RegisterMessage(CCLCMsg_LoadingProgress)

CCLCMsg_SplitPlayerConnect = _reflection.GeneratedProtocolMessageType('CCLCMsg_SplitPlayerConnect', (_message.Message,), dict(
  DESCRIPTOR = _CCLCMSG_SPLITPLAYERCONNECT,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CCLCMsg_SplitPlayerConnect)
  ))
_sym_db.RegisterMessage(CCLCMsg_SplitPlayerConnect)

CCLCMsg_CmdKeyValues = _reflection.GeneratedProtocolMessageType('CCLCMsg_CmdKeyValues', (_message.Message,), dict(
  DESCRIPTOR = _CCLCMSG_CMDKEYVALUES,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CCLCMsg_CmdKeyValues)
  ))
_sym_db.RegisterMessage(CCLCMsg_CmdKeyValues)

CSVCMsg_ServerInfo = _reflection.GeneratedProtocolMessageType('CSVCMsg_ServerInfo', (_message.Message,), dict(
  DESCRIPTOR = _CSVCMSG_SERVERINFO,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSVCMsg_ServerInfo)
  ))
_sym_db.RegisterMessage(CSVCMsg_ServerInfo)

CSVCMsg_ClassInfo = _reflection.GeneratedProtocolMessageType('CSVCMsg_ClassInfo', (_message.Message,), dict(

  class_t = _reflection.GeneratedProtocolMessageType('class_t', (_message.Message,), dict(
    DESCRIPTOR = _CSVCMSG_CLASSINFO_CLASS_T,
    __module__ = 'demoparser.protobufs.netmessages_pb2'
    # @@protoc_insertion_point(class_scope:CSVCMsg_ClassInfo.class_t)
    ))
  ,
  DESCRIPTOR = _CSVCMSG_CLASSINFO,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSVCMsg_ClassInfo)
  ))
_sym_db.RegisterMessage(CSVCMsg_ClassInfo)
_sym_db.RegisterMessage(CSVCMsg_ClassInfo.class_t)

CSVCMsg_SendTable = _reflection.GeneratedProtocolMessageType('CSVCMsg_SendTable', (_message.Message,), dict(

  sendprop_t = _reflection.GeneratedProtocolMessageType('sendprop_t', (_message.Message,), dict(
    DESCRIPTOR = _CSVCMSG_SENDTABLE_SENDPROP_T,
    __module__ = 'demoparser.protobufs.netmessages_pb2'
    # @@protoc_insertion_point(class_scope:CSVCMsg_SendTable.sendprop_t)
    ))
  ,
  DESCRIPTOR = _CSVCMSG_SENDTABLE,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSVCMsg_SendTable)
  ))
_sym_db.RegisterMessage(CSVCMsg_SendTable)
_sym_db.RegisterMessage(CSVCMsg_SendTable.sendprop_t)

CSVCMsg_Print = _reflection.GeneratedProtocolMessageType('CSVCMsg_Print', (_message.Message,), dict(
  DESCRIPTOR = _CSVCMSG_PRINT,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSVCMsg_Print)
  ))
_sym_db.RegisterMessage(CSVCMsg_Print)

CSVCMsg_SetPause = _reflection.GeneratedProtocolMessageType('CSVCMsg_SetPause', (_message.Message,), dict(
  DESCRIPTOR = _CSVCMSG_SETPAUSE,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSVCMsg_SetPause)
  ))
_sym_db.RegisterMessage(CSVCMsg_SetPause)

CSVCMsg_SetView = _reflection.GeneratedProtocolMessageType('CSVCMsg_SetView', (_message.Message,), dict(
  DESCRIPTOR = _CSVCMSG_SETVIEW,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSVCMsg_SetView)
  ))
_sym_db.RegisterMessage(CSVCMsg_SetView)

CSVCMsg_CreateStringTable = _reflection.GeneratedProtocolMessageType('CSVCMsg_CreateStringTable', (_message.Message,), dict(
  DESCRIPTOR = _CSVCMSG_CREATESTRINGTABLE,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSVCMsg_CreateStringTable)
  ))
_sym_db.RegisterMessage(CSVCMsg_CreateStringTable)

CSVCMsg_UpdateStringTable = _reflection.GeneratedProtocolMessageType('CSVCMsg_UpdateStringTable', (_message.Message,), dict(
  DESCRIPTOR = _CSVCMSG_UPDATESTRINGTABLE,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSVCMsg_UpdateStringTable)
  ))
_sym_db.RegisterMessage(CSVCMsg_UpdateStringTable)

CSVCMsg_VoiceInit = _reflection.GeneratedProtocolMessageType('CSVCMsg_VoiceInit', (_message.Message,), dict(
  DESCRIPTOR = _CSVCMSG_VOICEINIT,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSVCMsg_VoiceInit)
  ))
_sym_db.RegisterMessage(CSVCMsg_VoiceInit)

CSVCMsg_VoiceData = _reflection.GeneratedProtocolMessageType('CSVCMsg_VoiceData', (_message.Message,), dict(
  DESCRIPTOR = _CSVCMSG_VOICEDATA,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSVCMsg_VoiceData)
  ))
_sym_db.RegisterMessage(CSVCMsg_VoiceData)

CSVCMsg_FixAngle = _reflection.GeneratedProtocolMessageType('CSVCMsg_FixAngle', (_message.Message,), dict(
  DESCRIPTOR = _CSVCMSG_FIXANGLE,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSVCMsg_FixAngle)
  ))
_sym_db.RegisterMessage(CSVCMsg_FixAngle)

CSVCMsg_CrosshairAngle = _reflection.GeneratedProtocolMessageType('CSVCMsg_CrosshairAngle', (_message.Message,), dict(
  DESCRIPTOR = _CSVCMSG_CROSSHAIRANGLE,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSVCMsg_CrosshairAngle)
  ))
_sym_db.RegisterMessage(CSVCMsg_CrosshairAngle)

CSVCMsg_Prefetch = _reflection.GeneratedProtocolMessageType('CSVCMsg_Prefetch', (_message.Message,), dict(
  DESCRIPTOR = _CSVCMSG_PREFETCH,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSVCMsg_Prefetch)
  ))
_sym_db.RegisterMessage(CSVCMsg_Prefetch)

CSVCMsg_BSPDecal = _reflection.GeneratedProtocolMessageType('CSVCMsg_BSPDecal', (_message.Message,), dict(
  DESCRIPTOR = _CSVCMSG_BSPDECAL,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSVCMsg_BSPDecal)
  ))
_sym_db.RegisterMessage(CSVCMsg_BSPDecal)

CSVCMsg_SplitScreen = _reflection.GeneratedProtocolMessageType('CSVCMsg_SplitScreen', (_message.Message,), dict(
  DESCRIPTOR = _CSVCMSG_SPLITSCREEN,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSVCMsg_SplitScreen)
  ))
_sym_db.RegisterMessage(CSVCMsg_SplitScreen)

CSVCMsg_GetCvarValue = _reflection.GeneratedProtocolMessageType('CSVCMsg_GetCvarValue', (_message.Message,), dict(
  DESCRIPTOR = _CSVCMSG_GETCVARVALUE,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSVCMsg_GetCvarValue)
  ))
_sym_db.RegisterMessage(CSVCMsg_GetCvarValue)

CSVCMsg_Menu = _reflection.GeneratedProtocolMessageType('CSVCMsg_Menu', (_message.Message,), dict(
  DESCRIPTOR = _CSVCMSG_MENU,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSVCMsg_Menu)
  ))
_sym_db.RegisterMessage(CSVCMsg_Menu)

CSVCMsg_UserMessage = _reflection.GeneratedProtocolMessageType('CSVCMsg_UserMessage', (_message.Message,), dict(
  DESCRIPTOR = _CSVCMSG_USERMESSAGE,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSVCMsg_UserMessage)
  ))
_sym_db.RegisterMessage(CSVCMsg_UserMessage)

CSVCMsg_PaintmapData = _reflection.GeneratedProtocolMessageType('CSVCMsg_PaintmapData', (_message.Message,), dict(
  DESCRIPTOR = _CSVCMSG_PAINTMAPDATA,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSVCMsg_PaintmapData)
  ))
_sym_db.RegisterMessage(CSVCMsg_PaintmapData)

CSVCMsg_GameEvent = _reflection.GeneratedProtocolMessageType('CSVCMsg_GameEvent', (_message.Message,), dict(

  key_t = _reflection.GeneratedProtocolMessageType('key_t', (_message.Message,), dict(
    DESCRIPTOR = _CSVCMSG_GAMEEVENT_KEY_T,
    __module__ = 'demoparser.protobufs.netmessages_pb2'
    # @@protoc_insertion_point(class_scope:CSVCMsg_GameEvent.key_t)
    ))
  ,
  DESCRIPTOR = _CSVCMSG_GAMEEVENT,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSVCMsg_GameEvent)
  ))
_sym_db.RegisterMessage(CSVCMsg_GameEvent)
_sym_db.RegisterMessage(CSVCMsg_GameEvent.key_t)

CSVCMsg_GameEventList = _reflection.GeneratedProtocolMessageType('CSVCMsg_GameEventList', (_message.Message,), dict(

  key_t = _reflection.GeneratedProtocolMessageType('key_t', (_message.Message,), dict(
    DESCRIPTOR = _CSVCMSG_GAMEEVENTLIST_KEY_T,
    __module__ = 'demoparser.protobufs.netmessages_pb2'
    # @@protoc_insertion_point(class_scope:CSVCMsg_GameEventList.key_t)
    ))
  ,

  descriptor_t = _reflection.GeneratedProtocolMessageType('descriptor_t', (_message.Message,), dict(
    DESCRIPTOR = _CSVCMSG_GAMEEVENTLIST_DESCRIPTOR_T,
    __module__ = 'demoparser.protobufs.netmessages_pb2'
    # @@protoc_insertion_point(class_scope:CSVCMsg_GameEventList.descriptor_t)
    ))
  ,
  DESCRIPTOR = _CSVCMSG_GAMEEVENTLIST,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSVCMsg_GameEventList)
  ))
_sym_db.RegisterMessage(CSVCMsg_GameEventList)
_sym_db.RegisterMessage(CSVCMsg_GameEventList.key_t)
_sym_db.RegisterMessage(CSVCMsg_GameEventList.descriptor_t)

CSVCMsg_TempEntities = _reflection.GeneratedProtocolMessageType('CSVCMsg_TempEntities', (_message.Message,), dict(
  DESCRIPTOR = _CSVCMSG_TEMPENTITIES,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSVCMsg_TempEntities)
  ))
_sym_db.RegisterMessage(CSVCMsg_TempEntities)

CSVCMsg_PacketEntities = _reflection.GeneratedProtocolMessageType('CSVCMsg_PacketEntities', (_message.Message,), dict(
  DESCRIPTOR = _CSVCMSG_PACKETENTITIES,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSVCMsg_PacketEntities)
  ))
_sym_db.RegisterMessage(CSVCMsg_PacketEntities)

CSVCMsg_Sounds = _reflection.GeneratedProtocolMessageType('CSVCMsg_Sounds', (_message.Message,), dict(

  sounddata_t = _reflection.GeneratedProtocolMessageType('sounddata_t', (_message.Message,), dict(
    DESCRIPTOR = _CSVCMSG_SOUNDS_SOUNDDATA_T,
    __module__ = 'demoparser.protobufs.netmessages_pb2'
    # @@protoc_insertion_point(class_scope:CSVCMsg_Sounds.sounddata_t)
    ))
  ,
  DESCRIPTOR = _CSVCMSG_SOUNDS,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSVCMsg_Sounds)
  ))
_sym_db.RegisterMessage(CSVCMsg_Sounds)
_sym_db.RegisterMessage(CSVCMsg_Sounds.sounddata_t)

CSVCMsg_EntityMsg = _reflection.GeneratedProtocolMessageType('CSVCMsg_EntityMsg', (_message.Message,), dict(
  DESCRIPTOR = _CSVCMSG_ENTITYMSG,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSVCMsg_EntityMsg)
  ))
_sym_db.RegisterMessage(CSVCMsg_EntityMsg)

CSVCMsg_CmdKeyValues = _reflection.GeneratedProtocolMessageType('CSVCMsg_CmdKeyValues', (_message.Message,), dict(
  DESCRIPTOR = _CSVCMSG_CMDKEYVALUES,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSVCMsg_CmdKeyValues)
  ))
_sym_db.RegisterMessage(CSVCMsg_CmdKeyValues)

CSVCMsg_EncryptedData = _reflection.GeneratedProtocolMessageType('CSVCMsg_EncryptedData', (_message.Message,), dict(
  DESCRIPTOR = _CSVCMSG_ENCRYPTEDDATA,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSVCMsg_EncryptedData)
  ))
_sym_db.RegisterMessage(CSVCMsg_EncryptedData)

CSVCMsg_HltvReplay = _reflection.GeneratedProtocolMessageType('CSVCMsg_HltvReplay', (_message.Message,), dict(
  DESCRIPTOR = _CSVCMSG_HLTVREPLAY,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSVCMsg_HltvReplay)
  ))
_sym_db.RegisterMessage(CSVCMsg_HltvReplay)

CCLCMsg_HltvReplay = _reflection.GeneratedProtocolMessageType('CCLCMsg_HltvReplay', (_message.Message,), dict(
  DESCRIPTOR = _CCLCMSG_HLTVREPLAY,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CCLCMsg_HltvReplay)
  ))
_sym_db.RegisterMessage(CCLCMsg_HltvReplay)

CSVCMsg_Broadcast_Command = _reflection.GeneratedProtocolMessageType('CSVCMsg_Broadcast_Command', (_message.Message,), dict(
  DESCRIPTOR = _CSVCMSG_BROADCAST_COMMAND,
  __module__ = 'demoparser.protobufs.netmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSVCMsg_Broadcast_Command)
  ))
_sym_db.RegisterMessage(CSVCMsg_Broadcast_Command)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\200\001\000'))
_ESPLITSCREENMESSAGETYPE.has_options = True
_ESPLITSCREENMESSAGETYPE._options = _descriptor._ParseOptions(descriptor_pb2.EnumOptions(), _b('\020\001'))
# @@protoc_insertion_point(module_scope)
